import { DynamicNode} from '@/ua/DynamicNode';
import JSZip from "jszip";


export class ServerConfig {
    public buildInfo:any = {
		manufacturerName:"Emco GmbH",
		productName: "EMCO OPC UA Server",
		softwareVersion: "1.0.0"
		};
    public serverInfo:any = {
				applicationUri: "EMCO_OPCUA",
				productUri: "EMCO_OPCUA",
				applicationName: { "text": "EMCO_OPCUA", "locale": "en" }
			};

    public dynamics:DynamicNode[]=[];
    public nodesets:string[]=[];

    constructor(options: ServerConfigOptions) {
        this.buildInfo = options.buildInfo;
        this.serverInfo =  options.serverInfo; 
    }


    addDynamic(dyn:DynamicNode){
        this.dynamics.forEach((dyn, idx)=>{
            if(dyn.ident == dyn.ident){
                return false;
            }
        })
        this.dynamics.push(dyn);
        return true;
    }

    removeDynamic(ident:string){
        this.dynamics.forEach((dyn, idx)=>{
            if(dyn.ident == ident){
                this.dynamics.splice(idx,1);
                return true;
            }
        })
        return false;
    }

    toPlainObject(){
        let obj = {
            buildinfo: this.buildInfo,
            serverInfo: this.serverInfo,
            dynamics: []
        }    
        this.dynamics.forEach((dyn)=>{
            //obj.dynamics.push(dyn.toPlainObject());
        })
    }


    public exportConfig() {
        const zip = new JSZip();
        zip.file("server_config.json", JSON.stringify(this.toPlainObject()));
        return zip.generateAsync({type:'blob'});
    }
}


export interface ServerConfigOptions {
    buildInfo:{
		manufacturerName:"Emco GmbH",
		productName: "EMCO OPC UA Server",
		softwareVersion: "1.0.0"
		},
	serverInfo: {
				applicationUri: "EMCO_OPCUA",
				productUri: "EMCO_OPCUA",
				applicationName: { "text": "EMCO_OPCUA", "locale": "en" }
			}
}